from GameVisionTargetingModel.variables.model_settings \
    import                  \
    get_input_set,          \
    get_width,              \
    get_channels,           \
    get_height,             \
    get_number_of_labels,   \
    get_last_layer_multiplier

from GameVisionTargetingModel.variables.model_settings \
    import                  \
    set_width,              \
    set_height,             \
    set_channels,           \
    set_number_of_labels,   \
    set_last_layer_multiplier

from GameVisionTargetingModel.variables.normalise_settings \
    import \
    get_rescaling_multiplier, \
    set_rescaling_multiplier
