from GameVisionTargetingModel.models.classification.map.v1.setup.middle_layer.first \
    import generate_first_middle_layer

from GameVisionTargetingModel.models.classification.map.v1.setup.middle_layer.second \
    import generate_second_middle_layer

from GameVisionTargetingModel.models.classification.map.v1.setup.middle_layer.third \
    import generate_third_middle_layer

from GameVisionTargetingModel.models.classification.map.v1.setup.middle_layer.decision \
    import generate_decision_middle_layer

